@@ -447,7 +447,8 @@ impl ClearScreen {
 				}
 
 				if let Some(seq) = info.get::<ResetScrollback>() {
-					seq.expand().with(&mut ctx).to(w)?;
+					seq.expand().with(&mut ctx).to(&mut w)?;
+					w.flush()?;
 				}
 			}
 			Self::TerminfoScreen => {
@@ -768,7 +769,7 @@ mod unix {
 mod win {
 	use super::Error;
 
-	use std::{convert::TryFrom, io, mem::size_of, process::Command, ptr};
+	use std::{convert::TryFrom, io, mem::size_of, ptr};
 
 	use winapi::{
 		shared::minwindef::{DWORD, FALSE},
@@ -1058,17 +1059,6 @@ mod win {
 		}
 	}
 
-	// check for PackageManagement cmdlet, which was introduced in Win10
-	#[inline]
-	fn pwsh_package_management() -> Result<bool, Error> {
-		Ok(Command::new("powershell.exe")
-			.arg("-Command")
-			.arg("Get-Command -Module PackageManagement")
-			.output()?
-			.status
-			.success())
-	}
-
 	// attempt to set the bit, then undo it
 	fn vt_attempt() -> Result<bool, Error> {
 		let stdout = console_handle()?;
@@ -1106,16 +1096,12 @@ mod win {
 			return true;
 		}
 
-		if pwsh_package_management().unwrap_or(false) {
-			return true;
-		}
-
 		vt_attempt().unwrap_or(false)
 	}
 }
 
 #[cfg(not(unix))]
-#[allow(clippy::clippy::unnecessary_wraps)]
+#[allow(clippy::unnecessary_wraps)]
 mod unix {
 	use super::Error;
 
@@ -1129,7 +1115,7 @@ mod unix {
 }
 
 #[cfg(not(windows))]
-#[allow(clippy::clippy::unnecessary_wraps)]
+#[allow(clippy::unnecessary_wraps)]
 mod win {
 	use super::Error;
 
